==> ipqbdb-1.05.tar.gz: ipqbdb-1.05/ibd-report.sh <==
#! /bin/bash
#
# Report blocked addresses
#
# This script reads daemon log and prints a list of blocked addresses.
#
# A one or two digit numeric arguments limits the report to addresses
# that were caught at least that many times.
# An argument of ".0" is taken to read /var/log/daemon.log.0 instead,
# otherwise a the full path of the log file is accepted.
#
# Several assumptions are made about path and format of the log files.


dotzero=""
minlin=2
command=cat
filename=/var/log/daemon.log

while test $# -gt 0; do
	case "$1" in
		.[0-9]) dotzero=$1;;
		[0-9]|[0-9][0-9]) minlin="$1";;
		*) filename=$1
	esac
	shift
done

if [ -r "$filename$dotzero" ]; then
	:
elif [ -r "$filename$dotzero.gz" ]; then
	filename="$filename$dotzero.gz"
	dotzero=""
	command=zcat
fi

# assume the log starts with 15 characters date (May 29 18:34:16)
$command $filename$dotzero |\
sed -rn '/ibd-(parse|ban)/s/(^.{15})[^:]*: *(old|new) record for ([^,]*), *(.*)/\3 \1 \2 \4/p' |\
sort --key 1 --stable |\
(
	read ip line
	while test -n "$ip"; do
		declare -a report
		key=$ip
		if [[ "$line" =~ " old " ]]; then
			first_is_old=1
		else
			first_is_old=0
		fi
		while true; do
			report+=("$line")
			read ip line
			test "$key" = "$ip" || break
		done
		if [ ${#report[@]} -gt $minlin ]; then
			curl https://freegeoip.app/csv/$key
			dig +short $(echo $key | sed -rn 's/^([0-9]*)\.([0-9]*)\.([0-9]*)\.([0-9]*)$/\4.\3.\2.\1.abuse-contacts.abusix.org/p') txt
			printf "    %s\n" "${report[@]}"
			echo
			if [ $first_is_old -eq 1 ]; then
				printf "    %s\n\n" "$(ibd-del --ls-simple -i $key)"
			fi
		fi
		unset report
	done
)

==> ipqbdb-1.06.tar.gz: ipqbdb-1.06/ibd-report.sh <==
#! /bin/bash
#
# Report blocked addresses
#
# This script reads daemon log and prints a list of blocked addresses.
#
# A one or two digit numeric arguments limits the report to addresses
# that were caught at least that many times.
# An argument of ".0" is taken to read /var/log/daemon.log.0 instead,
# otherwise a the full path of the log file is accepted.
#
# Several assumptions are made about path and format of the log files.


dotzero=""
minlin=2
command=cat
filename=/var/log/daemon.log

while test $# -gt 0; do
	case "$1" in
		.[0-9]) dotzero=$1;;
		[0-9]|[0-9][0-9]) minlin="$1";;
		*) filename=$1
	esac
	shift
done

if [ -r "$filename$dotzero" ]; then
	:
elif [ -r "$filename$dotzero.gz" ]; then
	filename="$filename$dotzero.gz"
	dotzero=""
	command=zcat
fi

# assume the log starts with 15 characters date (May 29 18:34:16)
$command $filename$dotzero |\
sed -rn '/ibd-(parse|ban)/s/(^.{15})[^:]*: *(old|new) record for ([^,]*), *(.*)/\3 \1 \2 \4/p' |\
sort --key 1 --stable |\
(
	read ip line
	while test -n "$ip"; do
		declare -a report
		key=$ip
		if [[ "$line" =~ " old " ]]; then
			first_is_old=1
		else
			first_is_old=0
		fi
		while true; do
			report+=("$line")
			read ip line
			test "$key" = "$ip" || break
		done
		if [ ${#report[@]} -gt $minlin ]; then
			curl -s https://freegeoip.app/csv/$key
			abuserdap http://rdap.arin.net/bootstrap/ip/1$key
			printf "    %s\n" "${report[@]}"
			echo
			if [ $first_is_old -eq 1 ]; then
				printf "    %s\n\n" "$(ibd-del --ls-simple -i $key)"
			fi
		fi
		unset report
	done
)
